@@ -1,6 +1,7 @@
 '''
 Soil package.
 '''
+# pylint:disable=consider-using-from-import
 from soil.modulify import modulify
 from soil.data import data
 from soil.alias import alias
@@ -8,7 +9,9 @@ from soil import finder
 from soil.logger import logger
 import soil.connectors as connectors
 from soil.decorator import decorator
-from soil.task import task
+from soil.task import task, task_wait
+from soil.alerts import alerts
+from soil.dictionary import dictionary
 
 finder.install()
 
@@ -21,5 +24,8 @@ __all__ = [
     'logger',
     'connectors',
     'decorator',
-    'task'
+    'task',
+    'task_wait',
+    'alerts',
+    'dictionary'
 ]
