@@ -10,6 +10,6 @@ def alias(name: str, data_ref: DataStructure, roles: Optional[List[str]] = None)
     ''' Set an alias to a data reference'''
     # Force to get an id if there is none yet.
     if data_ref.id is None:
-        data_ref.get_data()
+        data_ref.get_id()
     assert isinstance(data_ref.id, str)
     set_alias(name, data_ref.id, roles)
