@@ -81,10 +81,10 @@ def _generate_code(public_api: List[str], package_type: str) -> str:
     code = ''
     if package_type == 'modules':
         for f in public_api:
-            code += 'from soil import modulify\n@modulify(_from_db=True)\ndef %s(*args, **kwargs):\n    pass\n\n' % f
+            code += f'from soil import modulify\n@modulify(_from_db=True)\ndef {f}(*args, **kwargs):\n    pass\n\n'
     if package_type == 'data_structures':
         for f in public_api:
-            code += 'class %s():\n    pass\n\n' % f
+            code += f'class {f}:\n    pass\n\n'
     return code
 
 
@@ -113,15 +113,17 @@ class CustomLoader(Loader):
         is_package = self.is_package
         if self.code is None and self.filename is not None:
             is_package = self.filename[-len('__init__.py'):] == '__init__.py'
-            with open(self.filename) as f:
+            with open(self.filename, encoding='utf-8') as f:
                 self.code = f.read()
         if self.code is not None and (
                 self.fullname[:len('soil.modules')] == 'soil.modules'
                 or self.fullname[:len('soil.data_structures')] == 'soil.data_structures'
         ):
-            if not self.from_db:
+            if not self.from_db and os.environ.get('PY_ENV', 'development') != 'test':
                 api.upload_module(self.fullname, self.code, is_package)
-            exec(self.code, vars(module))  # nosec
+            name = self.filename if self.filename is not None else self.fullname
+            compiled_module = compile(self.code, name, 'exec')
+            exec(compiled_module, vars(module))  # nosec
 
 
 def install() -> None:
