@@ -1,3 +1,4 @@
+#  pylint:disable=unused-argument
 '''
 This module defines the @modulify decorator.
 '''
@@ -13,6 +14,9 @@ def modulify(
         _func: Optional[Callable[..., List[DataStructure]]] = None,
         *,
         output_types: Optional[Callable] = None,
+        centralize: bool = False,
+        distribute: bool = False,
+        federating: bool = False,
         num_outputs: int = 1,
         _from_db: bool = False
 ) -> Callable:
