@@ -13,3 +13,15 @@ def task(modulified_module: Callable) -> Callable:
     def decorator(*args: DataStructure, **kwargs: Any) -> List[DataStructure]:
         return modulified_module(*args, **kwargs)
     return decorator
+
+
+def task_wait(futures: Any) -> Any:
+    '''
+    Wait until computation completes and gather results.
+
+    Accepts a future, nested container of futures, iterator, or queue.
+    The return type will match the input type.
+    Example:
+        result = tasks_wait([future1, future2])
+    '''
+    return futures
