@@ -3,7 +3,7 @@
 
 import unittest
 from unittest.mock import MagicMock
-from soil import task
+from soil import task, task_wait
 
 
 class TestTask(unittest.TestCase):
@@ -11,5 +11,7 @@ class TestTask(unittest.TestCase):
         mock_module = MagicMock()
         mock_module.return_value = 'ok'
         tasked = task(mock_module)
-        assert tasked(1, 2, 3, a=2, b=3) == 'ok'
+        future = tasked(1, 2, 3, a=2, b=3)
+        result = task_wait(future)
+        assert result == 'ok'
         mock_module.assert_called_once_with(1, 2, 3, a=2, b=3)
